# ksim

This is K-Scale's library for running simulation experiments.

## Installation

Install from PyPI:

```bash
pip install ksim
```

For more details, see the [documentation](https://docs.kscale.dev/docs/ksim).
